function y = EDFA_saturation(Optical_input,Unsat_GaindB,Sat_OutputdBm,IncludeNoise,NFdB)
%
% Usage: y = EDFA_saturation(Optical_input,Unsat_GaindB,Sat_OutputdBm,IncludeNoise,NFdB)
%
% Purpose = This module is to simulate an ideal EDFA (wavelength independent gain and noise figure).
%          with a saturable gain.
%
% Input(Optical_input) = Optical signal
% Output(y) = Amplified optical signal
%
%=== Physical Parameters=======
%
% Unsat_GaindB = Unsaturated gain in [dB]
%              = 20 (default)
% Sat_OutputdBm = Optical power[dBm] at the 3dB optical gain compression.
%               = 20 (default)
% IncludeNoise = 'Yes' or 'No'
%              = 'Yes' (default)
% NFdB = Noise figure in [dB]
%      = 5 (default)
%
% Note1) ASE noise modeled by a complex Gaussain process
% Note2) Single polarization assumed.
%
%------------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%====================================================================================
global SampleRate DataLength Ref_Frequency

if nargin<5, NFdB=5; end
if nargin<4, IncludeNoise = 'Yes'; end
if nargin<3, Sat_OutputdBm = 20; end
if nargin<2, Unsat_GaindB = 20; end

G_edfa_u = 10^(Unsat_GaindB/10); % Unsaturated EDFA gain in linear scale

% ===== Calculation of Saturated Gain =============
P_sat_int = 1e-3*10^(Sat_OutputdBm/10)*(G_edfa_u-2)/(log(2)*G_edfa_u); %Intrinsic saturation power[W]
P_in = PowerMeter(Optical_input); %Calculation of 'Average' Optical Power in [W]

save edfa_sat_gain P_sat_int P_in G_edfa_u; % 'G_edfa.m' will load 'edfa_sat_gain.mat' to use variables P_sat_int, P_in, and G_edfa_u 

options = optimset('TolFun',1e-4,'Display','off'); % Suppress displaying calculation process by 'fzero'
G_edfa_s = fzero('G_edfa',G_edfa_u,options); % 

if isnan(G_edfa_s)==1
    disp('EDFA_saturation: Input Power is too large!')
    return
end
%====================================================
%--- include ASE noise or not -------------------------------

if strcmp(IncludeNoise, 'No') == 1,

	y = sqrt(G_edfa_s)*Optical_input;

elseif strcmp(IncludeNoise, 'Yes') == 1, 

    %---------- ASE noise ----------------------------------------
    h_plank = 6.6256e-34; %[W sec^2] Plank's constant
    P_den_ase_r = .25*10^(NFdB/10)*(G_edfa_s-1)*h_plank*Ref_Frequency; %[W/Hz]
    E_ase_r =sqrt(P_den_ase_r*SampleRate)*randn(1,DataLength);
    P_den_ase_i = P_den_ase_r;
    E_ase_i =sqrt(P_den_ase_i*SampleRate)*randn(1,DataLength);

    E_ase = E_ase_r + 1i*E_ase_i; % Complex Gaussian Process
    %--------------------------------------------------------------
	E_sig_out = sqrt(G_edfa_s)*Optical_input;
	y = E_sig_out + E_ase ;
    
else
    % Display Error Message and Stop
    error('IncludeNoise allows only Yes or No. Please check your spelling.') 

end

delete('edfa_sat_gain.mat'); % delete the gain file after EDFA output