function y = E_FilterLPBessel(Elec_input,FilterOrder,BW3dB)
%
% Usage: y = E_FilterLPBessel(Elec_input,FilterOrder,BW3dB)
%
% Purpose = This module is to filter an input electrical signal 
%          with an Bessel lowpass filter.
%
% Input Signal(Elec_input) = Electrical Signal 
% Output Signal(y) = Electrical Signal 
%
% === Physical Parameters === 
% FilterOrder = positive integer [1,100]
%             = 3 (default)          
% BW3dB [Hz] = 3dB Bandwidth (positive frequency)
%            = 0.7*BitRate (default)
%
% f_sym BitRate (global variable)
%
% Note) n_3dB is defined to normalize the 3dB bandwidth for FilterOrder >=3 
%               (at Cutoff Frequency, filter attenuation is greater than 3dB for FilterOrder >=3)
%
%----------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
% Reference  1. Shammugan et al.,'Simulation of Communication Systems', Chapter 2, p69,  
%
%====================================================================================
global f_sym BitRate

if nargin<3,
   BW3dB = 0.7*BitRate;
end

if nargin<2,
   FilterOrder = 3;
end

if FilterOrder < 1 || FilterOrder > 100
  error('FilterOrder is out of range: ');


elseif FilterOrder == 1 || FilterOrder == 2;

	p = 1i*f_sym/BW3dB;
	p_center =(p == min(p));
	B(1,:) = 1+p; B(2,:) = 3 + 3*p + p.*p;

	T_bessel = B(FilterOrder,p_center)./B(FilterOrder,:);
  
else

	n_3dB = sqrt((2*FilterOrder-1)*log(2));
	%n_3dB will make 3dB bandwidth approximately equal to parameter value 'BW3dB' for FilterOrder >= 3
	p = 1i*f_sym/(BW3dB/n_3dB); % 
	p_center = (p == min(p));

	B(1,:) = 1+p; B(2,:) = 3 + 3*p + p.*p;

	  for k = 3:FilterOrder
	
			B(k,:) = (2*k-1)*B(k-1,:) + p.*p.*B(k-2,:);
  	  end

			T_bessel = B(FilterOrder,p_center)./B(FilterOrder,:);

end

%========= Filtering input signal with the electrical Bessel filter =================
Elec_f = fft(Elec_input);
Filtered = fftshift(T_bessel).*Elec_f; %'ifftshift' inverses 'fftshift'

%====== Filtered Ekectrical Signal in time domain ============
y = real(ifft(Filtered)); % Remove spurious imaginary part
