function [Out Optimum_SampleTime] = EyeAnalyzer_Optimum(InSignal,info_bit,OutType)
%
% Usage: [Out Optimum_SampleTime] = EyeAnalyzer_Optimum(InSignal,info_bit,OutType)
%
% Purpose = This module is to anaylzer an eye diagram with the synchronied pulse train.
%
% Input1 (InSignal) = Single channel signal (optical/electrical), Size = [1 x DataLength]
% Input2 (info_bit) = Bit sequence sent at the transmitter
%
% Output1 (Out) = User Specified Output Quantity
% Output2 (Optimum_SampleTime) = Relative to bit frame (Optimum value to maximize Output1)   
%
% Three figures will be generated.
%     1) figure1: Eye diagram with sampling instant
%     2) figire2: Histogram of sampled data
%     3) figire3: Eye Lids
%
%==== Simulation Parameters ===============
%  OutType = 'Q_value' (default) (|mean(marks)-mean(spaces)|/(std1+std0))
%          = 'EyeHeight' {(mean(marks)-3*std(marks)) - (mean(spaces)+3*std(spaces))}
%          = 'ExtinctionRatio' (mean(marks)/mean(spaces))
%          = 'EyeClosure' (min(marks) - max(spaces))
%
% Note 1) When the bit number is relatively small ( < 128), 'Synchronizer' may not work properly. 
%         In that case, this module will display "Eye Closed" message errorously. By increasing bit numbers, this problem can be solved. 
%
%------------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%=====================================================================
global samplesperbit Bits SampleRate BitRate

if nargin <3, OutType='Q_value'; end

s_type = ~isreal(InSignal);

if s_type == 1; %
    InSignal = InSignal.*conj(InSignal);
end

marks = mean(info_bit)*Bits; spaces = Bits - marks; % Number of Marks and Spaces in Bits

[Syn_out ref_pulse] = Synchronizer(InSignal,info_bit);

%--------------------------------------------------------------------------

    marks_v = Syn_out(ref_pulse==1);spaces_v = Syn_out(ref_pulse==0);
    marks_v = reshape(marks_v,samplesperbit,marks); spaces_v = reshape(spaces_v,samplesperbit,spaces);

    ms1 = mean(marks_v'); % Size = [1 samplesperbit], Mean values of Mark Bits at each sample points from 1 to samplesperbit 
    ms0 = mean(spaces_v'); % Size = [1 samplesperbit], Mean values of Space Bits at each sample points from 1 to samplesperbit 
    std1 = std(marks_v'); % Size = [1 samplesperbit], STD of Mark Bits at each sample points from 1 to samplesperbit
    std0 = std(spaces_v'); % Size = [1 samplesperbit], STD of Space Bits at each sample points from 1 to samplesperbit

    min_mark = min(marks_v');
    max_space = max(spaces_v');
  
  %  To Check the eye quality 
  if min_mark < max_space

        EyePlotter2(InSignal,info_bit)
        disp('Eye is closed!  Will stop further calculations.')  
        disp(' ')  
        return      
  end
  %------------------------------------------------------------------------
          
       if  strcmp(OutType, 'EyeClosure') == 1
       
          Out = max(min_mark - max_space); Optimum_SampleTime = find(Out==(min_mark - max_space))/samplesperbit;
          fprintf('Eye Closure = %8.2e \n', Out);
          fprintf('Optimum SampleTime = %8.2e \n', Optimum_SampleTime);
          
       elseif  strcmp(OutType, 'EyeHeight') == 1 
       
          Out = max((ms1-3*std1) - (ms0+3*std0)); Optimum_SampleTime = find(Out==((ms1-3*std1) - (ms0+3*std0)))/samplesperbit;
          fprintf('Eye Height = %8.2e \n', Out);
          fprintf('Optimum SampleTime = %8.2e \n', Optimum_SampleTime);
          
       elseif strcmp(OutType, 'ExtinctionRatio') == 1 
       
          Out = max(ms1./ms0); Optimum_SampleTime = find(Out==(ms1./ms0))/samplesperbit;
          fprintf('Extinction Ratio = %6.2f \n', Out);
          fprintf('Optimum SampleTime = %8.2e \n', Optimum_SampleTime);
          
       elseif strcmp(OutType, 'Q_value') == 1
          
          Out = max(abs(ms1-ms0)./(std1+std0)); Optimum_SampleTime = find(Out==(abs(ms1-ms0)./(std1+std0)))/samplesperbit;
          fprintf('Q value = %6.2f \n', Out);
          fprintf('Optimum SampleTime = %8.2e \n', Optimum_SampleTime);
             
       else
           
          disp('  ')
          disp('  ')
          disp('Please check your OutType spelling!')
          disp('  ')
          disp('  ')
        return
        
       end
       
        EyePlotter2(InSignal,info_bit)
        hold on
        t_SampleTime = Optimum_SampleTime*(1e9/BitRate)*ones(1,20); %  EyePlotter2 plots eye in [ns].
        max_mark = max(max(marks_v));
        plot(t_SampleTime,1e3*linspace(0,max_mark*1.3,20),'k','LineWidth',2)
        text(t_SampleTime(1),1e3*max_mark*1.3,'Sampling Instant','FontSize',12)
        

 %  To plot Histogram    
          c_position = samplesperbit/2; 
          hist_data = [marks_v(c_position,:) spaces_v(c_position,:)];
          bin_number = min(50,length(hist_data));
          figure      
          hist(hist_data,bin_number); 
          h_data = hist(hist_data,bin_number);
          hmax = max(h_data); dh = hmax/10;
          xlabel('Magnitude of Sampled Data','FontSize',12),title('Histogram of Sampled Data of the Received Signal','FontSize',12)
          text(ms0(c_position)+std0(c_position),hmax-dh,['mean0 = ' num2str(ms0(c_position))])
          text(ms0(c_position)+std0(c_position),hmax-2*dh,['std0 = ' num2str(std0(c_position))])
          text(ms0(c_position)+std0(c_position),hmax-4*dh,['mean1 = ' num2str(ms1(c_position))])
          text(ms0(c_position)+std0(c_position),hmax-5*dh,['std1 = ' num2str(std1(c_position))])

  %  To plot Eye Lid
  
         t_eye = 1e9*(0:1/SampleRate:(1/BitRate - 1/SampleRate));% 1 bit periods in [ns] unit
         figure
         plot(t_eye,1e3*min_mark,t_eye,1e3*max_space,'r','LineWidth',2)
         grid on
         title('Eye Lids Plot','FontSize',12)
         xlabel('time [ns]','FontSize',12)
         ylabel('Magnitude [mA or mV]','FontSize',12)
       
       
  


