function y = PhotoDiode_APD(E_optical,Responsivity,AvalacheMul,IonizationCoeff,ShotNoiseFactor,ThermalNoiseDen,...
                DarkCurrMult,DarkCurrNonMult)
%
% Usage : y = PhotoDiode_APD(E_optical,Responsivity,AvalacheMul,IonizationCoeff,ShotNoiseFactor,ThermalNoiseDen,...
%                DarkCurrMult,DarkCurrNonMult)
%
% Purpose = This module acts as an avalanche photodiode with additive Gaussian noise.
%
% Input Signal (E_optical) = Received Optical Signal 
% Output Signal (y) = Photo Detected Electrical Signal 
%
% === Physical Parameters  with default values === 
% Responsivity  = 1.0 [A/W], [0,2]
% AvalacheMul = 1   [1,1000]
% IonizationCoeff = 1  [1e-3, 1]
% ShotNoiseFactor = 1   (1 if shot noise included, 0 if not)
% ThermalNoiseDen = 1e-22 [A^2/Hz], Power Spectral Density of Thermal noise 
% DarkCurrMult = 0 [A], [0,10e-6]
% DarkCurrNonMult = 0 [A], [0.10e-6]
%
% (global variables) DataLength SampleRate 
%
% Note) Shot Noise is modeled with Gaussian distribution.

%------------------------------------------------------------
% $ Revision: 1.0 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%==============================================================
global DataLength SampleRate 

if nargin<8,
   DarkCurrNonMult = 0;% [A]
end
if nargin<7,
    DarkCurrMult = 0; % [A]
end
if nargin<6,
    ThermalNoiseDen = 1e-22;% [A^2/Hz];
end
if nargin<5,
   ShotNoiseFactor = 1;
end
if nargin<4,
   IonizationCoeff = 1;
end
if nargin<3,
   AvalacheMul = 1; 
end
if nargin<2, 
  Responsivity = 1.0; %[A/W]
end

%======== PhotoDetection Process =============
P_received = E_optical.*conj(E_optical);
i_gen = Responsivity*P_received;
i_gen_ave = Responsivity*sum(P_received)/length(P_received);

%===== Multiplication =======

i_sig = AvalacheMul*i_gen;
i_dark = AvalacheMul*DarkCurrMult+DarkCurrNonMult;

%===== NoiseGeneration =======
q = 1.602e-19; %[C]=[A sec]=[A/Hz] electron charge

F_M = IonizationCoeff*AvalacheMul + (2-1/AvalacheMul)*(1-IonizationCoeff);

n_shot_mul = 2*q*(DarkCurrMult+i_gen_ave)*SampleRate;
n_shot_non = 2*q*DarkCurrNonMult*SampleRate;
n_shot = n_shot_mul*AvalacheMul^2*F_M + n_shot_non;

i_nshot = ShotNoiseFactor*sqrt(n_shot)*randn(1,DataLength);
i_nth = sqrt(ThermalNoiseDen*SampleRate)*randn(1,DataLength);

%======= Total output current of APD ======

y = i_sig + i_dark + i_nth + i_nshot;
