function y = PulseGaussianOptical(info_bits,PeakPower,FWHM,GaussianOrder,Chirp,...
                                  ExcessPulseSlots,CenterPosition) 
%                              
% Usage: y = PulseGaussianOptical(info_bits,PeakPower,FWHM,GaussianOrder,Chirp,...
%                                  ExcessPulseSlots,CenterPosition)                               
%
% Purpose = This function generates Gaussain or super-Gaussian optical pulses,
%           modulated by a bit sequence.
%
% Input (info_bits) = bit sequence 
% Output (y) = Gaussian, or super-Gaussian optical (field) pulse
%
% ===== Physical Parameters ======
% PeakPower ; [W] default = 1e-3;
% FWHM, Full width at half maximum power; [sec] default = 1/3/BitRate;
% GaussianOrder ; Order of super-Gaussain function, default = 1 (Gaussian)
% Chirp ;   Chirp factor, default = 0
% ExcessPulseSlots; Number of extra bit slot to consider neighboring bits, default = 3;
% CenterPosition ; Relative position of the pulse peak wrt bit frame  %[-0.5 0.5] default = 0 (center)
%
% (global variables) BitRate Bits samplesperbit SampleRate 
%
% Note) y (single pulse) = sqrt(PeakPower)*exp(-0.5*log(2)*(1+1i*Chirp)*abs(2*t_bits/FWHM).^(2*GaussianOrder))
%
%------------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%==========================================================================================
global BitRate Bits samplesperbit SampleRate

if nargin<7,
   CenterPosition = 0;% 
end
if nargin<6,
   ExcessPulseSlots = 3;% 
end
if nargin<5,
   Chirp = 0;% 
end
if nargin<4,
   GaussianOrder = 1;% 
end
if nargin<3,
   FWHM = 1/3/BitRate;% 
end
if nargin<2,
   PeakPower = 1e-3;% [W]
end

%--------------------------------------------------------------------------

Tb = 1/BitRate;
t_b = -ExcessPulseSlots*Tb:1/SampleRate:(ExcessPulseSlots*Tb-1/SampleRate);
t_bits = t_b - CenterPosition*Tb;
GaussP = sqrt(PeakPower)*exp(-0.5*log(2)*(1+1i*Chirp)*abs(2*t_bits/FWHM).^(2*GaussianOrder))*exp(1i); % Single Pulse  
% exp(ii) will make GaussP a complex.
GaussT = info_bits'*GaussP;


% Now for delayed pulses

   for k=1:Bits

     y1(k,:)=[zeros(1,samplesperbit*(k-1)) GaussT(k,:) zeros(1,(Bits-k)*samplesperbit)];
       
   end
   
pulses1 = sum(y1);   

r_Excess = ExcessPulseSlots - 0.5; 

y = pulses1((r_Excess*samplesperbit+1):(length(pulses1)-r_Excess*samplesperbit));

