function [yt,yf] = SingleModeFiber_Lin(OpticalFieldIn,Fiber_Length,FiberAttenuation,Dispersion,DispersionSlope)
%
% Usage: [yt,yf] = SingleModeFiber_Lin(OpticalFieldIn,Fiber_Length,FiberAttenuation,Dispersion,DispersionSlope)
%
% Purpose = To calculate optical fields in sigle mode fiber when the fiber nonlinearity is absent. 
%          (Included physical effects = Attenuation, first order GVD,second-order GVD)
%
% Input(OpticalFieldIn) = Optical signal (time domain)
% Output1(yt) = Optical signal (time domain)
% Output2(yf) = Optical signal (frquency domain)
%
%=== Physical Parameters with Typical values of SMF-28 =========
%
%  Fiber_Length = 50e3; %[m]
%  FiberAttenuation = 0.2e-3; %[dB/m]
%  Dispersion = 16e-6;   %[s/m^2]
%  DispersionSlope = 0.08e3;   %[s/m^3]
%
%  (global variables) Ref_Frequency  f_sym  [Hz];
%
%------------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%==========================================================================
global Ref_Frequency f_sym 

if nargin <5
    DispersionSlope=0.08e3;   %[s/m^3]   
end    
if nargin<4,
    Dispersion = 16e-6;   %[s/m^2]
end
if nargin<3,
   FiberAttenuation = 0.2e-3; %[dB/m]
end
if nargin<2,
   Fiber_Length = 50e3; %[m]
end
%==========================================================================
c_light = 2.99793e8;       %[m/sec] speed of light
alpha = FiberAttenuation/(10*log10(exp(1))); %[1/m] Power Loss in linear scale

w_range = 2*pi*(Ref_Frequency + f_sym); %physical optical frequency range
w_base = 2*pi*f_sym; % base band optical frequency

%=== Linear Opeartor=============
beta2 = -2*pi*c_light*Dispersion./(w_range.^2);
beta3 = (2*pi*c_light)^2*DispersionSlope./(w_range.^4) + 4*pi*c_light*Dispersion./(w_range.^3);
lin = 1i*beta2.*w_base.^2/2 + 1i*beta3.*w_base.^3/6 - alpha/2;  %(d/dt)=(-iw) as in Agrawal's (w_base is symmetrical)
A_com_f = fft(OpticalFieldIn); % Input composite signal to fiber in frequency domain 

yf = fftshift(exp(Fiber_Length*lin)).*A_com_f;
yt = ifft(yf);

