function [y,info_bits] = Tx_PulseGaussianOptical(PeakPower,FWHM,GaussianOrder,Chirp,...
                         ExcessPulseSlots,CenterPosition,PreSpaces,PostSpaces)
%
% Usage: [y,info_bits] = Tx_PulseGaussianOptical(PeakPower,FWHM,GaussianOrder,Chirp,...
%                        ExcessPulseSlots,CenterPosition, PreSpaces,PostSpaces)                                 
%
% Purpose = This function simulates a transmitter generating Gaussain or super-Gaussian optical pulses,
%           modulated by a bit sequence.
%
% Tx_PulseGaussianOptical = PRBS generator + PulseGaussianOptical
%
% Input = Not required.
% Output1(y) = Gaussian, or super-Gaussian optical pulses with info_bits for BER calculation at the receiver.
% Output2(info_bits) = info_bits for BER calculation at the receiver.
%
% ===== Physical Parameters ======
% PeakPower ; [W] default = 1e-3;
% FWHM, Full width at half maximum power; [sec] default = 1/3/BitRate;
% GaussianOrder ; Order of super-Gaussain function, default = 1 (Gaussian)
% Chirp ;   Chirp factor, default = 0
% ExcessPulseSlots; Number of extra bit slot to consider neighboring bits, default = 3;
% CenterPosition ; Relative position of the pulse peak wrt bit frame %[-0.5 0.5] default = 0 (center)
%
% PreSpaces = 2 (default); % number of leading zero bits, infobits_PRBS
% PostSpaces = 2 (default); % number of trailing zero bits, infobits_PRBS
%
% Note) y (single pulse) = sqrt(PeakPower)*exp(-0.5*log(2)*(1+1i*Chirp)*abs(2*t_bits/FWHM).^(2*GaussianOrder))
%
%------------------------------------------------------------
% $ Revision: 1.0 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------
%
%==========================================================================================
global BitRate 

if nargin <8
    PostSpaces = 2;   
end    
if nargin<7,
    PreSpaces = 2;
end
if nargin<6,
   CenterPosition = 0;% 
end
if nargin<5,
   ExcessPulseSlots = 3;% 
end
if nargin<4,
   Chirp = 0;% 
end
if nargin<3,
   GaussianOrder = 1;% 
end
if nargin<2,
   FWHM = 1/3/BitRate;% 
end
if nargin==0,
   PeakPower = 1e-3;% [W]
end
%==================================================================
info_bits = infobits_PRBS(PreSpaces,PostSpaces); 
y = PulseGaussianOptical(info_bits,PeakPower,FWHM,GaussianOrder,Chirp,...
                                  ExcessPulseSlots,CenterPosition); 


